@@ -12,7 +12,7 @@ from tiddlyweb.util import sha
 from tiddlywebplugins.utils import get_store
 
 
-__version__ = '0.9.9'
+__version__ = '0.9.10'
 
 
 ANY_NAMESPACE = 'any'
@@ -268,7 +268,7 @@ class Store(StorageInterface):
         if cached_users:
             users = cached_users
         else:
-            bags = list(self.cached_storage.list_users())
+            users = list(self.cached_storage.list_users())
             self._mc.set(key, users)
         return users
 
